import { createStackNavigator, StackNavigationProp } from "@react-navigation/stack"
import React from "react"
import { View } from "react-native"
import OutdoorMap, { AuthTabsMapRouteProp } from "../components/Map/MainMapComponent/OutdoorMap"
import IndoorMap from "../components/Map/MainMapComponent/IndoorMap"
import { AuthTabsNavigationProp, AuthTabsParamList } from "./AuthorizedNavigator"
import { RouteProp } from "@react-navigation/native"

const MapStackNavigator = createStackNavigator()

export type MapStackParamList = {
    Outdoor: {selectedLandmark: string, selectedLandmarks: string[]},
    Indoor: React.FC,
}

export type MapStackNavigationProp = StackNavigationProp<MapStackParamList>



interface MapNavigatorProps {
    authNavigation: AuthTabsNavigationProp
    route: AuthTabsMapRouteProp
}

const MapNavigator: React.FC<MapNavigatorProps> = ({authNavigation, route}) => {
    return (
        <MapStackNavigator.Navigator initialRouteName="Outdoor">
            <MapStackNavigator.Screen name="Outdoor" >
                {({navigation}) => <OutdoorMap route={route} mapNavigation={navigation} authNavigation={authNavigation} />}
            </MapStackNavigator.Screen>
            <MapStackNavigator.Screen name="Indoor" component={IndoorMap} />
        </MapStackNavigator.Navigator>
    )
}

export default MapNavigator